@@ -68,7 +68,7 @@ import org.springframework.web.util.UrlPathHelper;
  */
 public class GrailsWebRequest extends DispatcherServletWebRequest  {
 
-    private static final String FORWARD_CALLED = "org.codehaus.groovy.grails.FORWARD_CALLED";
+    private static final String FORWARD_CALLED = GrailsApplicationAttributes.FORWARD_ISSUED;
     private static final String REDIRECT_CALLED = GrailsApplicationAttributes.REDIRECT_ISSUED;
 
     private static final Class<? extends GrailsApplicationAttributes> grailsApplicationAttributesClass = GrailsFactoriesLoader.loadFactoryClasses(GrailsApplicationAttributes.class, GrailsWebRequest.class.getClassLoader()).get(0);
@@ -360,8 +360,7 @@ public class GrailsWebRequest extends DispatcherServletWebRequest  {
         final HttpServletRequest currentRequest = getCurrentRequest();
         return renderView &&
                 !getCurrentResponse().isCommitted() &&
-                currentRequest.getAttribute(REDIRECT_CALLED) == null &&
-                currentRequest.getAttribute(FORWARD_CALLED) == null;
+                currentRequest.getAttribute(REDIRECT_CALLED) == null;
     }
 
     public String getId() {
