@@ -246,8 +246,8 @@ class ProjectGenerationRequest {
 		if (this.type != null) {
 			ProjectType result = metadata.getProjectTypes().get(this.type);
 			if (result == null) {
-				throw new ReportableException(
-						("No project type with id '" + this.type + "' - check the service capabilities (--list)"));
+				throw new ReportableException(("No project type with id '" + this.type
+						+ "' - check the service capabilities (--list)"));
 			}
 			return result;
 		}
@@ -287,8 +287,8 @@ class ProjectGenerationRequest {
 
 	private static void filter(Map<String, ProjectType> projects, String tag,
 			String tagValue) {
-		for (Iterator<Map.Entry<String, ProjectType>> it = projects.entrySet().iterator(); it
-				.hasNext();) {
+		for (Iterator<Map.Entry<String, ProjectType>> it = projects.entrySet()
+				.iterator(); it.hasNext();) {
 			Map.Entry<String, ProjectType> entry = it.next();
 			String value = entry.getValue().getTags().get(tag);
 			if (!tagValue.equals(value)) {
