@@ -160,8 +160,8 @@ public class ExtendedGroovyClassLoader extends GroovyClassLoader {
 		@Override
 		protected Class<?> createClass(byte[] code, ClassNode classNode) {
 			Class<?> createdClass = super.createClass(code, classNode);
-			ExtendedGroovyClassLoader.this.classResources.put(classNode.getName()
-					.replace(".", "/") + ".class", code);
+			ExtendedGroovyClassLoader.this.classResources
+					.put(classNode.getName().replace(".", "/") + ".class", code);
 			return createdClass;
 		}
 	}
