@@ -56,9 +56,11 @@ import groovy.lang.GroovyCodeSource;
  * <ul>
  * <li>{@link CompilerAutoConfiguration} strategies will be read from
  * <code>META-INF/services/org.springframework.boot.cli.compiler.CompilerAutoConfiguration</code>
- * (per the standard java {@link ServiceLoader} contract) and applied during compilation</li>
+ * (per the standard java {@link ServiceLoader} contract) and applied during compilation
+ * </li>
  *
- * <li>Multiple classes can be returned if the Groovy source defines more than one Class</li>
+ * <li>Multiple classes can be returned if the Groovy source defines more than one Class
+ * </li>
  *
  * <li>Generated class files can also be loaded using
  * {@link ClassLoader#getResource(String)}</li>
@@ -94,8 +96,8 @@ public class GroovyCompiler {
 
 		GrapeEngineInstaller.install(grapeEngine);
 
-		this.loader.getConfiguration().addCompilationCustomizers(
-				new CompilerAutoConfigureCustomizer());
+		this.loader.getConfiguration()
+				.addCompilationCustomizers(new CompilerAutoConfigureCustomizer());
 		if (configuration.isAutoconfigure()) {
 			this.compilerAutoConfigurations = ServiceLoader
 					.load(CompilerAutoConfiguration.class);
@@ -110,8 +112,8 @@ public class GroovyCompiler {
 				this.loader, resolutionContext, this.compilerAutoConfigurations));
 		this.transformations.add(new GroovyBeansTransformation());
 		if (this.configuration.isGuessDependencies()) {
-			this.transformations.add(new ResolveDependencyCoordinatesTransformation(
-					resolutionContext));
+			this.transformations.add(
+					new ResolveDependencyCoordinatesTransformation(resolutionContext));
 		}
 		for (ASTTransformation transformation : ServiceLoader
 				.load(SpringBootAstTransformation.class)) {
@@ -173,8 +175,8 @@ public class GroovyCompiler {
 	 * @throws CompilationFailedException
 	 * @throws IOException
 	 */
-	public Class<?>[] compile(String... sources) throws CompilationFailedException,
-			IOException {
+	public Class<?>[] compile(String... sources)
+			throws CompilationFailedException, IOException {
 
 		this.loader.clearCache();
 		List<Class<?>> classes = new ArrayList<Class<?>>();
@@ -272,8 +274,8 @@ public class GroovyCompiler {
 		public void call(SourceUnit source, GeneratorContext context, ClassNode classNode)
 				throws CompilationFailedException {
 
-			ImportCustomizer importCustomizer = new SmartImportCustomizer(source,
-					context, classNode);
+			ImportCustomizer importCustomizer = new SmartImportCustomizer(source, context,
+					classNode);
 			ClassNode mainClassNode = getMainClass(source.getAST().getClasses());
 
 			// Additional auto configuration
@@ -288,10 +290,9 @@ public class GroovyCompiler {
 								GroovyCompiler.this.configuration, context, source,
 								classNode);
 					}
-					autoConfiguration
-							.apply(GroovyCompiler.this.loader,
-									GroovyCompiler.this.configuration, context, source,
-									classNode);
+					autoConfiguration.apply(GroovyCompiler.this.loader,
+							GroovyCompiler.this.configuration, context, source,
+							classNode);
 				}
 			}
 			importCustomizer.call(source, context, classNode);
