@@ -45,10 +45,8 @@ public class SpringBootCompilerAutoConfiguration extends CompilerAutoConfigurati
 
 	@Override
 	public void applyImports(ImportCustomizer imports) {
-		imports.addImports(
-				"javax.annotation.PostConstruct",
-				"javax.annotation.PreDestroy",
-				"groovy.util.logging.Log",
+		imports.addImports("javax.annotation.PostConstruct",
+				"javax.annotation.PreDestroy", "groovy.util.logging.Log",
 				"org.springframework.stereotype.Controller",
 				"org.springframework.stereotype.Service",
 				"org.springframework.stereotype.Component",
